document.addEventListener("DOMContentLoaded", () => {
  let geofeeds = [];

  // Sample data for dropdowns
  const countries = {
    US: "United States",
    GB: "United Kingdom",
    CA: "Canada",
  };

  const regions = {
    US: { "US-TX": "Texas", "US-CA": "California" },
    GB: { "GB-LND": "London", "GB-MAN": "Manchester" },
    CA: { "CA-ON": "Ontario", "CA-BC": "British Columbia" },
  };

  const cities = {
    "US-TX": ["Austin", "Houston", "Dallas"],
    "US-CA": ["Los Angeles", "San Francisco", "San Diego", "Perris"],
    "GB-LND": ["London", "Westminster"],
    "GB-MAN": ["Manchester"],
    "CA-ON": ["Toronto", "Ottawa"],
    "CA-BC": ["Vancouver", "Victoria"],
  };

  // Populate country dropdown
  const countrySelect = document.getElementById("country");
  Object.entries(countries).forEach(([code, name]) => {
    const option = new Option(name, code);
    countrySelect.add(option);
  });

  // Handle country change
  countrySelect.addEventListener("change", (e) => {
    const regionSelect = document.getElementById("region");
    const citySelect = document.getElementById("city");

    regionSelect.innerHTML = '<option value="">Select Region</option>';
    citySelect.innerHTML = '<option value="">Select City</option>';

    if (e.target.value) {
      regionSelect.disabled = false;
      Object.entries(regions[e.target.value]).forEach(([code, name]) => {
        const option = new Option(name, code);
        regionSelect.add(option);
      });
    } else {
      regionSelect.disabled = true;
      citySelect.disabled = true;
    }
  });

  // Handle region change
  document.getElementById("region").addEventListener("change", (e) => {
    const citySelect = document.getElementById("city");
    citySelect.innerHTML = '<option value="">Select City</option>';

    if (e.target.value) {
      citySelect.disabled = false;
      cities[e.target.value].forEach((city) => {
        const option = new Option(city, city);
        citySelect.add(option);
      });
    } else {
      citySelect.disabled = true;
    }
  });

  // Handle form submission
  document.getElementById("geofeedForm").addEventListener("submit", (e) => {
    e.preventDefault();

    const entry = {
      ipPrefix: document.getElementById("ipPrefix").value,
      country: document.getElementById("country").value,
      region: document.getElementById("region").value,
      city: document.getElementById("city").value,
      postalCode: document.getElementById("postalCode").value,
    };

    geofeeds.push(entry);
    updateTable();
    e.target.reset();
  });

  // Download CSV
  document.getElementById("downloadBtn").addEventListener("click", () => {
    const csv = geofeeds
      .map(
        (entry) =>
          `${entry.ipPrefix},${entry.country},${entry.region},${entry.city},${entry.postalCode}`,
      )
      .join("\n");

    const blob = new Blob([csv], { type: "text/csv" });
    const url = window.URL.createObjectURL(blob);
    const a = document.createElement("a");
    a.href = url;
    a.download = "geofeed.csv";
    a.click();
    window.URL.revokeObjectURL(url);
  });

  // Clear all entries
  document.getElementById("clearBtn").addEventListener("click", () => {
    if (confirm("Are you sure you want to clear all entries?")) {
      geofeeds = [];
      updateTable();
    }
  });

  function updateTable() {
    const tbody = document.querySelector("#geofeedTable tbody");
    tbody.innerHTML = "";

    geofeeds.forEach((entry, index) => {
      const tr = document.createElement("tr");
      tr.innerHTML = `
        <td>${entry.ipPrefix}</td>
        <td>${countries[entry.country] || ""}</td>
        <td>${regions[entry.country]?.[entry.region] || ""}</td>
        <td>${entry.city}</td>
        <td>${entry.postalCode}</td>
        <td>
          <button onclick="removeEntry(${index})" class="danger-button">Remove</button>
        </td>
      `;
      tbody.appendChild(tr);
    });
  }

  // Make removeEntry function global
  window.removeEntry = (index) => {
    geofeeds.splice(index, 1);
    updateTable();
  };
});
